# REPLICATION MATERIAL FOR:
# "Input from Whom? Public Reactions to Consultation Measures"
# Anthony Kevins (Loughborough University)
# Political Studies

library(tidyverse)
library(effects)
library(stargazer)
library(ggthemes)
library(ggeffects)
library(gridExtra)
library(scales)
library(table1) 
library(htmltools)

### DATA PREP

# Set directory to where you've downloaded data 
setwd("file/location/here")

# Read data file 
unrep_full <- read_csv("Input_From_Whom.csv")

# Main analysis looks only at anti-bill respondents who also believe the majority is anti-bill
unrep <- subset(unrep_full, pro_bill == 0 & agree_with_majority == 1)

# Prep labels for descriptive table
unrep_full <- unrep_full %>%
    mutate(age = factor(age, levels = 2:7,
                        labels = c("18-24",
                                   "25-34",
                                   "35-44",
                                   "45-54",
                                   "55-64",
                                   "65+")))

unrep_full <- unrep_full %>%
    mutate(race_cat = factor(race_cat, levels = 1:7,
                        labels = c("Black",
                                   "Asian",
                                   "Native American",
                                   "Hispanic",
                                   "White",
                                   "Other",
                                   "Mixed Race")))

unrep_full <- unrep_full %>%
    mutate(ownincome = factor(ownincome, levels = 1:5,
                        labels = c("Bottom 25%",
                                   "Just above Bottom 25%",
                                   "Somewhere around the Middle",
                                   "Just below Top 25%",
                                   "Top 25%")))

unrep_full <- unrep_full %>%
    mutate(householdincome  = factor(householdincome, levels = 1:5,
                              labels = c("Bottom 25%",
                                         "Just above Bottom 25%",
                                         "Somewhere around the Middle",
                                         "Just below Top 25%",
                                         "Top 25%")))


unrep_full <- unrep_full %>%
    mutate(pid_str = factor(pid_str, levels = 1:4,
                        labels = c("Independent",
                                   "Lean",
                                   "Not strong",
                                   "Strong partisan")))


unrep_full <- unrep_full %>%
    mutate(female = factor(female, levels = 0:1,
                           labels = c("Male",
                                      "Female")))

unrep_full <- unrep_full %>%
    mutate(sample = factor(sample, levels = 0:1,
                           labels = c("No",
                                      "Yes")))

unrep_full <- unrep_full %>%
    mutate(pid_3 = factor(pid_3, levels = 1:3,
                           labels = c("Democrat",
                                      "Independent",
                                      "Republican")))

# Convert numeric variables to factors
unrep <- unrep %>%
    mutate(maj_favoured_outcome = factor(maj_favoured_outcome, levels = 0:1,
                                         labels = c("Majority Opposes Outcome",
                                                    "Majority Favours Outcome")))

unrep <- unrep %>%
    mutate(consultation = factor(consultation, levels = 1:4,
                                 labels = c("None", 
                                            "Polling", 
                                            "Interested", 
                                            "Affected")))

unrep <- unrep %>%
    mutate(favoured_outcome = factor(favoured_outcome, levels = 0:2,
                                     labels = c("Bill Passed", 
                                                "Neutral", 
                                                "Bill Failed")))

unrep <- unrep %>%
    mutate(favoured_outcome_bin = factor(favoured_outcome_bin, levels = 0:1,
                                         labels = c("Bill Passed", 
                                                    "Bill Failed")))

unrep <- unrep %>%
    mutate(treatment = factor(treatment, levels = c(1, 3, 4, 6, 7, 9, 10, 12),
                              labels = c("Control - Dislike Outcome", 
                                         "Control - Like Outcome", 
                                         "Polling - Dislike Outcome", 
                                         "Polling - Like Outcome ", 
                                         "Interested - Dislike Outcome", 
                                         "Interested - Like Outcome", 
                                         "Affected - Dislike Outcome", 
                                         "Affected - Like Outcome")))

### REGRESSIONS (Standard models, plus models controlling for respondent's own income or household income)

# Perceived Responsiveness Models 
model1 <- lm(responsiveness ~ favoured_outcome * consultation, 
             na.action=na.omit,
             data=unrep)

model1_own <- lm(responsiveness ~ favoured_outcome * consultation + ownincome, 
                 na.action=na.omit,
                 data=unrep)

model1_hh <- lm(responsiveness ~ favoured_outcome * consultation + householdincome, 
                na.action=na.omit,
                data=unrep)

# Alternative Perceived Responsiveness measure (without explained item in index)

model1_alt <- lm(responsiveness_alt ~ favoured_outcome * consultation, 
                 na.action=na.omit,
                 data=unrep)

# Decision Acceptance Models 

model2 <- lm(index ~ favoured_outcome * consultation, 
             na.action=na.omit,
             data=unrep)

model2_own <- lm(index ~ favoured_outcome * consultation + ownincome, 
                 na.action=na.omit,
                 data=unrep)

model2_hh <- lm(index ~ favoured_outcome * consultation + householdincome, 
                na.action=na.omit,
                data=unrep)

#External Efficacy Models
model3 <- lm(index ~ favoured_outcome_bin * consultation * extefficacy_factor,
             na.action=na.omit,
             data=unrep)

model3_own <- lm(index ~ favoured_outcome_bin * consultation * extefficacy_factor + ownincome, 
                 na.action=na.omit,
                 data=unrep)

model3_hh <- lm(index ~ favoured_outcome_bin * consultation * extefficacy_factor + householdincome, 
                na.action=na.omit,
                data=unrep)

#Internal Efficacy Models 

model4 <- lm(index ~ favoured_outcome_bin * intefficacy_factor * consultation,
             na.action=na.omit,
             data=unrep)

model4_own <- lm(index ~ favoured_outcome_bin * intefficacy_factor * consultation + ownincome, 
                 na.action=na.omit,
                 data=unrep)

model4_hh <- lm(index ~ favoured_outcome_bin * intefficacy_factor * consultation + householdincome, 
                na.action=na.omit,
                data=unrep)

### FIGURES

## Figure 1 

# Generate by group means and confidence intervals
eff1 <- effect("favoured_outcome * consultation", model1, typical="mean", se = c(level = .835))
eff1r <- cbind(eff1$x,fit=eff1$fit,lower=eff1$lower,higher=eff1$upper)
eff1r <- eff1r[order(eff1r$favoured_outcome,eff1r$consultation),]
rownames(eff1r) <- NULL
eff1r$treat <- as.numeric(rownames(eff1r)) 
eff1r$consultation <- factor(x = eff1r$consultation, levels = c("None", 
                                                                "Polling", 
                                                                "Interested", 
                                                                "Affected"))
eff1r$favoured_outcome <- factor(x = eff1r$favoured_outcome, levels = c("Bill Passed", 
                                                                        "Neutral", 
                                                                        "Bill Failed"))
eff1r <- eff1r[with(eff1r, order(favoured_outcome, consultation)), ]

# Extract by-group significance levels (comparison with control group mean)
p.values1 <- summary(model1)$coefficients[2:5,4] # Extract direct effect p-values from original model

p.values2 <- lm(responsiveness ~ relevel(favoured_outcome, ref = "Bill Failed")
                * consultation, 
                na.action=na.omit,
                data=unrep) # Model with alternative factor baseline
p.values2 <- summary(p.values2)$coefficients[2:5,4] # Extract direct effect p-values

p.values <- c(p.values1, p.values2) 
p.signif <- symnum(p.values, 
                   corr = FALSE, 
                   na = FALSE, 
                   cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1), 
                   symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '"))
p.signif[c(1, 5)] <- "' '" # Delete intercept coefficients 

# Graph
ggplot(eff1r, aes(x = consultation, 
                  y = fit)) +
    geom_pointrange(aes(ymin = lower, ymax = higher), shape = 18, colour = fivethirtyeight_pal()(1)) + 
    geom_text(aes(label = paste(round(fit, digits=2), "^", p.signif)), 
              size = 3, hjust = -0.15, colour = fivethirtyeight_pal()(1),show.legend = FALSE, parse = TRUE) + 
    labs(x = "Consultation", y = "Responsiveness")+
    theme(legend.title = element_blank()) + 
    theme_hc() + 
    theme(strip.background = element_rect(fill = alpha(fivethirtyeight_pal()(1), .025))) +
    facet_grid(~ favoured_outcome) +
    ggsave("Figure 1.eps", width = 7, height = 3.5, device=cairo_ps, fallback_resolution = 600)

## Figure 2

# Generate by group means and confidence intervals
eff2 <- effect("favoured_outcome * consultation", model2, typical="mean", se = c(level = .835))
eff2r <- cbind(eff2$x,fit=eff2$fit,lower=eff2$lower,higher=eff2$upper)
eff2r <- eff2r[order(eff2r$favoured_outcome,eff2r$consultation),]
rownames(eff2r) <- NULL
eff2r$treat <- as.numeric(rownames(eff2r)) 
eff2r$consultation <- factor(x = eff2r$consultation, levels = c("None", 
                                                                "Polling", 
                                                                "Interested", 
                                                                "Affected"))
eff2r$favoured_outcome <- factor(x = eff2r$favoured_outcome, levels = c("Bill Passed", 
                                                                        "Neutral", 
                                                                        "Bill Failed"))
eff2r <- eff2r[with(eff2r, order(favoured_outcome, consultation)), ]

# Extract by-group significance levels (comparison with control group mean)
p.values1 <- summary(model2)$coefficients[2:5,4] # Extract direct effect p-values from original model

p.values2 <- lm(index ~ relevel(favoured_outcome, ref = "Bill Failed")
                * consultation, 
                na.action=na.omit,
                data=unrep) # Model with alternative factor baseline
p.values2 <- summary(p.values2)$coefficients[2:5,4] # Extract direct effect p-values

p.values <- c(p.values1, p.values2) 
p.signif <- symnum(p.values, 
                   corr = FALSE, 
                   na = FALSE, 
                   cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1), 
                   symbols = c("bold('***')", "bold('**')", "bold('*')", "'+'", "' '"))
p.signif[c(1, 5)] <- "' '" # Delete intercept coefficients 


# Graph
ggplot(eff2r, aes(x = consultation, 
                  y = fit)) +
    geom_pointrange(aes(ymin = lower, ymax = higher), shape = 18, colour = fivethirtyeight_pal()(1)) + 
    geom_text(aes(label = paste(round(fit, digits=2), "^", p.signif)), 
              size = 3, hjust = -0.15, colour = fivethirtyeight_pal()(1),show.legend = FALSE, parse = TRUE) + 
    labs(x = "Consultation", y = "Decision Acceptance")+
    theme(legend.title = element_blank()) + 
    theme_hc() + 
    theme(strip.background = element_rect(fill = alpha(fivethirtyeight_pal()(1), .025))) +
    scale_colour_fivethirtyeight() +
    facet_grid(~ favoured_outcome) +
    ggsave("Figure 2.eps", width = 7, height = 3.5, device=cairo_ps, fallback_resolution = 600)


## Figure 3

# Graphs exclude extreme efficacy values (x-scale from 5th to 95th percentile)
xrange <- quantile(unrep$extefficacy_factor, probs = c(.05, .95))

# Bill Passed
predictions <- ggpredict(model3, terms = c("extefficacy_factor",
                                           "consultation [None, Polling]",
                                           "favoured_outcome_bin [Bill Passed]"),
                         ci.lvl = 0.835)

p1 <- ggplot(predictions, aes(x, predicted, colour = group, fill = group)) +
    geom_line(aes(linetype = group)) +
    geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.1, linetype = 0) +
    theme_hc() +
    theme(strip.background = element_rect(fill = alpha(fivethirtyeight_pal()(1), .025))) +
    scale_colour_fivethirtyeight() +
    scale_fill_fivethirtyeight() +
    scale_linetype_manual(values=c("dotted", "dashed")) +
    labs(
        title = "Bill Passed",
        x= " ",
        y = "Decision Acceptance",
        colour = " ",
        linetype = " "
    ) +
    facet_wrap(~facet, labeller = labeller(facet = c(`Bill Passed` = "Poll Constituents"))) +
    guides(fill = FALSE, color = guide_legend(override.aes = list(fill = NA))) +
    coord_cartesian(xlim = xrange, ylim = c(0, 5)) + 
    scale_y_continuous(breaks = seq(0, 10, by=1))

predictions <- ggpredict(model3, terms = c("extefficacy_factor",
                                           "consultation [None, Interested]",
                                           "favoured_outcome_bin [Bill Passed]"),
                         ci.lvl = 0.835)

p2 <- ggplot(predictions, aes(x, predicted, colour = group, fill = group)) +
    geom_line(aes(linetype = group)) +
    geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.1, linetype = 0) +
    theme_hc() +
    theme(strip.background = element_rect(fill = alpha(fivethirtyeight_pal()(1), .025))) +
    scale_colour_fivethirtyeight() +
    scale_fill_fivethirtyeight() +
    scale_linetype_manual(values=c("dotted", "dashed")) +
    labs(
        title = " ",
        x= "External Efficacy",
        y = " ",
        colour = " ",
        linetype = " "
    ) +
    facet_wrap(~facet, labeller = labeller(facet = c(`Bill Passed` = "Consult Interested"))) +
    guides(fill = FALSE, color = guide_legend(override.aes = list(fill = NA))) +
    coord_cartesian(xlim = xrange, ylim = c(0, 5)) + 
    scale_y_continuous(breaks = seq(0, 10, by=1))

predictions <- ggpredict(model3, terms = c("extefficacy_factor",
                                           "consultation [None, Affected]",
                                           "favoured_outcome_bin [Bill Passed]"),
                         ci.lvl = 0.835)

p3 <- ggplot(predictions, aes(x, predicted, colour = group, fill = group)) +
    geom_line(aes(linetype = group)) +
    geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.1, linetype = 0) +
    theme_hc() +
    theme(strip.background = element_rect(fill = alpha(fivethirtyeight_pal()(1), .025))) +
    scale_colour_fivethirtyeight() +
    scale_fill_fivethirtyeight() +
    scale_linetype_manual(values=c("dotted", "dashed")) +
    labs(
        title = " ",
        x= " ",
        y = " ",
        colour = " ",
        linetype = " "
    ) +
    facet_wrap(~facet, labeller = labeller(facet = c(`Bill Passed` = "Consult Affected"))) +
    guides(fill = FALSE, color = guide_legend(override.aes = list(fill = NA))) +
    coord_cartesian(xlim = xrange, ylim = c(0, 5)) + 
    scale_y_continuous(breaks = seq(0, 10, by=1))

#Bill Failed

predictions <- ggpredict(model3, terms = c("extefficacy_factor",
                                           "consultation [None, Polling]",
                                           "favoured_outcome_bin [Bill Failed]"),
                         ci.lvl = 0.835)

p4 <- ggplot(predictions, aes(x, predicted, colour = group, fill = group)) +
    geom_line(aes(linetype = group)) +
    geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.1, linetype = 0) +
    theme_hc() +
    theme(strip.background = element_rect(fill = alpha(fivethirtyeight_pal()(1), .025))) +
    scale_colour_fivethirtyeight() +
    scale_fill_fivethirtyeight() +
    scale_linetype_manual(values=c("dotted", "dashed")) +
    labs(
        title = "Bill Failed",
        x= " ",
        y = "Decision Acceptance",
        colour = " ",
        linetype = " "
    ) +
    facet_wrap(~facet, labeller = labeller(facet = c(`Bill Failed` = "Poll Constituents"))) +
    guides(fill = FALSE, color = guide_legend(override.aes = list(fill = NA))) +
    coord_cartesian(xlim = xrange, ylim = c(4, 9)) + 
    scale_y_continuous(breaks = seq(0, 10, by=1))

predictions <- ggpredict(model3, terms = c("extefficacy_factor",
                                           "consultation [None, Interested]",
                                           "favoured_outcome_bin [Bill Failed]"),
                         ci.lvl = 0.835)

p5 <- ggplot(predictions, aes(x, predicted, colour = group, fill = group)) +
    geom_line(aes(linetype = group)) +
    geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.1, linetype = 0) +
    theme_hc() +
    theme(strip.background = element_rect(fill = alpha(fivethirtyeight_pal()(1), .025))) +
    scale_colour_fivethirtyeight() +
    scale_fill_fivethirtyeight() +
    scale_linetype_manual(values=c("dotted", "dashed")) +
    labs(
        title = " ",
        x= "External Efficacy",
        y = " ",
        colour = " ",
        linetype = " "
    ) +
    facet_wrap(~facet, labeller = labeller(facet = c(`Bill Failed` = "Consult Interested"))) +
    guides(fill = FALSE, color = guide_legend(override.aes = list(fill = NA))) +
    coord_cartesian(xlim = xrange, ylim = c(4, 9)) + 
    scale_y_continuous(breaks = seq(0, 10, by=1))

predictions <- ggpredict(model3, terms = c("extefficacy_factor",
                                           "consultation [None, Affected]",
                                           "favoured_outcome_bin [Bill Failed]"),
                         ci.lvl = 0.835)

p6 <- ggplot(predictions, aes(x, predicted, colour = group, fill = group)) +
    geom_line(aes(linetype = group)) +
    geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.1, linetype = 0) +
    theme_hc() +
    theme(strip.background = element_rect(fill = alpha(fivethirtyeight_pal()(1), .025))) +
    scale_colour_fivethirtyeight() +
    scale_fill_fivethirtyeight() +
    scale_linetype_manual(values=c("dotted", "dashed")) +
    labs(
        title = " ",
        x= " ",
        y = " ",
        colour = " ",
        linetype = " "
    ) +
    facet_wrap(~facet, labeller = labeller(facet = c(`Bill Failed` = "Consult Affected"))) +
    guides(fill = FALSE, color = guide_legend(override.aes = list(fill = NA))) +
    coord_cartesian(xlim = xrange, ylim = c(4, 9)) + 
    scale_y_continuous(breaks = seq(0, 10, by=1))

g <- arrangeGrob(p1, p2, p3, p4, p5, p6, nrow = 2)


ggsave(file="Figure 3.eps", g, width = 7, height = 8, device=cairo_ps, fallback_resolution = 600)


## Figure 4

# Graphs exclude extreme efficacy values (x-scale from 5th to 95th percentile)
xrange <- quantile(unrep$intefficacy_factor, probs = c(.05, .95))

# Bill Passed
predictions <- ggpredict(model4, terms = c("intefficacy_factor",
                                           "consultation [None, Polling]",
                                           "favoured_outcome_bin [Bill Passed]"),
                         ci.lvl = 0.835)

p1 <- ggplot(predictions, aes(x, predicted, colour = group, fill = group)) +
    geom_line(aes(linetype = group)) +
    geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.1, linetype = 0) +
    theme_hc() +
    theme(strip.background = element_rect(fill = alpha(fivethirtyeight_pal()(1), .025))) +
    scale_colour_fivethirtyeight() +
    scale_fill_fivethirtyeight() +
    scale_linetype_manual(values=c("dotted", "dashed")) +
    labs(
        title = "Bill Passed",
        x= " ",
        y = "Decision Acceptance",
        colour = " ",
        linetype = " "
    ) +
    facet_wrap(~facet, labeller = labeller(facet = c(`Bill Passed` = "Poll Constituents"))) +
    guides(fill = FALSE, color = guide_legend(override.aes = list(fill = NA))) +
    coord_cartesian(xlim = xrange, ylim = c(1, 4)) + 
    scale_y_continuous(breaks = seq(0, 10, by=1))

predictions <- ggpredict(model4, terms = c("intefficacy_factor",
                                           "consultation [None, Interested]",
                                           "favoured_outcome_bin [Bill Passed]"),
                         ci.lvl = 0.835)

p2 <- ggplot(predictions, aes(x, predicted, colour = group, fill = group)) +
    geom_line(aes(linetype = group)) +
    geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.1, linetype = 0) +
    theme_hc() +
    theme(strip.background = element_rect(fill = alpha(fivethirtyeight_pal()(1), .025))) +
    scale_colour_fivethirtyeight() +
    scale_fill_fivethirtyeight() +
    scale_linetype_manual(values=c("dotted", "dashed")) +
    labs(
        title = " ",
        x= "Internal Efficacy",
        y = " ",
        colour = " ",
        linetype = " "
    ) +
    facet_wrap(~facet, labeller = labeller(facet = c(`Bill Passed` = "Consult Interested"))) +
    guides(fill = FALSE, color = guide_legend(override.aes = list(fill = NA))) +
    coord_cartesian(xlim = xrange, ylim = c(1, 4)) + 
    scale_y_continuous(breaks = seq(0, 10, by=1))

predictions <- ggpredict(model4, terms = c("intefficacy_factor",
                                           "consultation [None, Affected]",
                                           "favoured_outcome_bin [Bill Passed]"),
                         ci.lvl = 0.835)

p3 <- ggplot(predictions, aes(x, predicted, colour = group, fill = group)) +
    geom_line(aes(linetype = group)) +
    geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.1, linetype = 0) +
    theme_hc() +
    theme(strip.background = element_rect(fill = alpha(fivethirtyeight_pal()(1), .025))) +
    scale_colour_fivethirtyeight() +
    scale_fill_fivethirtyeight() +
    scale_linetype_manual(values=c("dotted", "dashed")) +
    labs(
        title = " ",
        x= " ",
        y = " ",
        colour = " ",
        linetype = " "
    ) +
    facet_wrap(~facet, labeller = labeller(facet = c(`Bill Passed` = "Consult Affected"))) +
    guides(fill = FALSE, color = guide_legend(override.aes = list(fill = NA))) +
    coord_cartesian(xlim = xrange, ylim = c(1, 4)) + 
    scale_y_continuous(breaks = seq(0, 10, by=1))

#Bill Failed

predictions <- ggpredict(model4, terms = c("intefficacy_factor",
                                           "consultation [None, Polling]",
                                           "favoured_outcome_bin [Bill Failed]"),
                         ci.lvl = 0.835)

p4 <- ggplot(predictions, aes(x, predicted, colour = group, fill = group)) +
    geom_line(aes(linetype = group)) +
    geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.1, linetype = 0) +
    theme_hc() +
    theme(strip.background = element_rect(fill = alpha(fivethirtyeight_pal()(1), .025))) +
    scale_colour_fivethirtyeight() +
    scale_fill_fivethirtyeight() +
    scale_linetype_manual(values=c("dotted", "dashed")) +
    labs(
        title = "Bill Failed",
        x= " ",
        y = "Decision Acceptance",
        colour = " ",
        linetype = " "
    ) +
    facet_wrap(~facet, labeller = labeller(facet = c(`Bill Failed` = "Poll Constituents"))) +
    guides(fill = FALSE, color = guide_legend(override.aes = list(fill = NA))) +
    coord_cartesian(xlim = xrange, ylim = c(5, 8)) + 
    scale_y_continuous(breaks = seq(0, 10, by=1))

predictions <- ggpredict(model4, terms = c("intefficacy_factor",
                                           "consultation [None, Interested]",
                                           "favoured_outcome_bin [Bill Failed]"),
                         ci.lvl = 0.835)

p5 <- ggplot(predictions, aes(x, predicted, colour = group, fill = group)) +
    geom_line(aes(linetype = group)) +
    geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.1, linetype = 0) +
    theme_hc() +
    theme(strip.background = element_rect(fill = alpha(fivethirtyeight_pal()(1), .025))) +
    scale_colour_fivethirtyeight() +
    scale_fill_fivethirtyeight() +
    scale_linetype_manual(values=c("dotted", "dashed")) +
    labs(
        title = " ",
        x= "Internal Efficacy",
        y = " ",
        colour = " ",
        linetype = " "
    ) +
    facet_wrap(~facet, labeller = labeller(facet = c(`Bill Failed` = "Consult Interested"))) +
    guides(fill = FALSE, color = guide_legend(override.aes = list(fill = NA))) +
    coord_cartesian(xlim = xrange, ylim = c(5, 8)) + 
    scale_y_continuous(breaks = seq(0, 10, by=1))

predictions <- ggpredict(model4, terms = c("intefficacy_factor",
                                           "consultation [None, Affected]",
                                           "favoured_outcome_bin [Bill Failed]"),
                         ci.lvl = 0.835)

p6 <- ggplot(predictions, aes(x, predicted, colour = group, fill = group)) +
    geom_line(aes(linetype = group)) +
    geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = 0.1, linetype = 0) +
    theme_hc() +
    theme(strip.background = element_rect(fill = alpha(fivethirtyeight_pal()(1), .025))) +
    scale_colour_fivethirtyeight() +
    scale_fill_fivethirtyeight() +
    scale_linetype_manual(values=c("dotted", "dashed")) +
    labs(
        title = " ",
        x= " ",
        y = " ",
        colour = " ",
        linetype = " "
    ) +
    facet_wrap(~facet, labeller = labeller(facet = c(`Bill Failed` = "Consult Affected"))) +
    guides(fill = FALSE, color = guide_legend(override.aes = list(fill = NA))) +
    coord_cartesian(xlim = xrange, ylim = c(5, 8)) + 
    scale_y_continuous(breaks = seq(0, 10, by=1))

g <- arrangeGrob(p1, p2, p3, p4, p5, p6, nrow = 2)

ggsave(file="Figure 4.eps", g, width = 7, height = 8, device=cairo_ps, fallback_resolution = 600)

## Appendix Figure 1

#External Efficacy 

## Graph predicted values at 25th, 50th, and 75th percentile of efficacy

predictions <- ggpredict(model3, terms = c("extefficacy_factor [quart2]", # 25th, 50th, and 75th percentile of efficacy
                                           "consultation",
                                           "favoured_outcome_bin"),
                         ci.lvl = 0.835)

# Labels for graphing

x_interquartile <- round(quantile(unrep$extefficacy_factor, probs = c(.25, .5, .75)), 2) # NB: ggpredict rounds to 2 digits

my_labels <- c('bolditalic(Q)[1]', 'bolditalic(Q)[2]', 'bolditalic(Q)[3]')

temp <- predictions %>%
    mutate(x = factor(x, levels = c(x_interquartile[1], x_interquartile[2], x_interquartile[3]),
                      labels = c(paste0(x_interquartile, '~(', my_labels, ')'))))

# Graph
external <- ggplot(temp, aes(x, predicted, colour = group, shape = group)) +
    geom_pointrange(aes(ymin = conf.low, ymax = conf.high),
                    position = position_dodge(width = 0.2)) +
    theme_hc() +
    theme(strip.background = element_rect(fill = alpha(fivethirtyeight_pal()(1), .025))) +
    scale_colour_economist() +
    labs(
        title = "Panel A",
        x = "External Efficacy",
        y = "Decision Acceptance",
        colour = " ",
        shape = " "
    ) +
    facet_wrap(~facet) +
    guides(shape = guide_legend(override.aes = list(fill = NA))) +
    scale_y_continuous(breaks = seq(0, 10, by=2)) +
    scale_x_discrete(labels = parse(text = levels(temp$x))) 

# Internal Efficacy 

## Graph predicted values at 25th, 50th, and 75th percentile of efficacy

predictions <- ggpredict(model4, terms = c("intefficacy_factor [quart2]", # 25th, 50th, and 75th percentile of efficacy
                                           "consultation",
                                           "favoured_outcome_bin"),
                         ci.lvl = 0.835)

# Labels for graphing

x_interquartile <- round(quantile(unrep$intefficacy_factor, probs = c(.25, .5, .75)), 2) # NB: ggpredict rounds to 2 digits

my_labels <- c('bolditalic(Q)[1]', 'bolditalic(Q)[2]', 'bolditalic(Q)[3]')

temp <- predictions %>%
    mutate(x = factor(x, levels = c(x_interquartile[1], x_interquartile[2], x_interquartile[3]),
                      labels = c(paste0(x_interquartile, '~(', my_labels, ')'))))

# Graph
internal <- ggplot(temp, aes(x, predicted, colour = group, shape = group)) +
    geom_pointrange(aes(ymin = conf.low, ymax = conf.high),
                    position = position_dodge(width = 0.2)) +
    theme_hc() +
    theme(strip.background = element_rect(fill = alpha(fivethirtyeight_pal()(1), .025))) +
    scale_colour_economist() +
    labs(
        title = "Panel B",
        x = "Internal Efficacy",
        y = "Decision Acceptance",
        colour = " ",
        shape = " "
    ) +
    facet_wrap(~facet) +
    guides(shape = guide_legend(override.aes = list(fill = NA))) +
    scale_y_continuous(breaks = seq(0, 10, by=2)) +
    scale_x_discrete(labels = parse(text = levels(temp$x)))

# Combine Panels

grid.arrange(external, internal, nrow = 2)

g <- arrangeGrob(external, internal, nrow = 2)
ggsave(file="Appendix Figure 1.eps", g, width = 7, height = 8, device=cairo_ps, fallback_resolution = 600)


### TABLES
## Note: to view properly formatted tables, open files with an internet browser (e.g. Firefox)

## Descriptive Tables

# Demographic Table (both full sample and censored sample)

labels <- list(
    variables=list(female = "Sex", 
                   race_cat = "Race", 
                   age = "Age Bracket", 
                   householdincome = "Household Income",
                   ownincome = "Personal Income", 
                   pid_3 = "Partisan ID", 
                   pid_str = "Partisan Strength"),
    groups=list("", "Included in Analysis?"))

strata <- c(list(Total=unrep_full), split(unrep_full, unrep_full$sample)) # Set order 

Appendix_Table_1 <- table1(strata, labels, groupspan=c(1, 2))
save_html(Appendix_Table_1, file = "Appendix Table 1")

# Treatment Group Split 

labels <- list(
    variables=list(female = "Sex", 
                   race_cat = "Race", 
                   age = "Age Bracket", 
                   householdincome = "Household Income",
                   ownincome = "Personal Income", 
                   pid_3 = "Partisan ID", 
                   pid_str = "Partisan Strength"),
    groups=list("", "Treatment Group"))

strata <- c(list(Total=unrep), split(unrep, unrep$treatment)) # Set order 

Online_Appendix_Table_1 <- table1(strata, labels, groupspan=c(1, 12))
save_html(Online_Appendix_Table_1, file = "Online Appendix Table 1")

# Note: to view proper formatting of these two tables, you'll need to copy/paste
Online_Appendix_Table_1
Appendix_Table_1


## Regression Tables 

stargazer(model1, 
          dep.var.labels=c("Perceived<br>Responsiveness"),
          covariate.labels=c("Bill Failed", 
                             "Consultation: Polling", "Consultation: Interested", "Consultation: Affected",
                             "Bill Failed * Polling", "Bill Failed * Interested", "Bill Failed * Affected",
                             "Just above Bottom 25%", "Around the Middle", "Just below Top 25%", "Top 25%"), 
          single.row = TRUE, no.space=TRUE, 
          star.cutoffs = c(.1, .05, .01, .001), star.char = c("+", "*", "**", "***"),
          notes = c("+ p<0.1; * p<0.05; ** p<0.01; *** p<0.001"), notes.append = FALSE,
          type = "html", out = "Appendix Table 2")

stargazer(model1, model1_alt, 
          dep.var.labels=c("Perceived<br>Responsiveness<br>(with Explained)","Perceived<br>Responsiveness (without<br>Explained)"),
          covariate.labels=c("Bill Failed", 
                             "Consultation: Polling", "Consultation: Interested", "Consultation: Affected",
                             "Bill Failed * Polling", "Bill Failed * Interested", "Bill Failed * Affected"),
          single.row = TRUE, no.space=TRUE, 
          star.cutoffs = c(.1, .05, .01, .001), star.char = c("+", "*", "**", "***"),
          notes = c("+ p<0.1; * p<0.05; ** p<0.01; *** p<0.001"), notes.append = FALSE,
          type = "html", out = "Online Appendix Table 2")

stargazer(model1_own, 
          dep.var.labels=c("Perceived<br>Responsiveness"),
          order = c(1, 2, 3, 4, 9, 10, 11),
          covariate.labels=c("Bill Failed", 
                             "Consultation: Polling", "Consultation: Interested", "Consultation: Affected",
                             "Bill Failed * Polling", "Bill Failed * Interested", "Bill Failed * Affected",
                             "Just above Bottom 25%", "Around the Middle", "Just below Top 25%", "Top 25%"), 
          single.row = TRUE, no.space=TRUE, 
          star.cutoffs = c(.1, .05, .01, .001), star.char = c("+", "*", "**", "***"),
          notes = c("+ p<0.1; * p<0.05; ** p<0.01; *** p<0.001"), notes.append = FALSE,
          type = "html", out = "Online Appendix Table 3")

stargazer(model1_hh, 
          dep.var.labels=c("Perceived<br>Responsiveness"),
          order = c(1, 2, 3, 4, 9, 10, 11),
          covariate.labels=c("Bill Failed", 
                             "Consultation: Polling", "Consultation: Interested", "Consultation: Affected",
                             "Bill Failed * Polling", "Bill Failed * Interested", "Bill Failed * Affected",
                             "Just above Bottom 25%", "Around the Middle", "Just below Top 25%", "Top 25%"), 
          single.row = TRUE, no.space=TRUE, 
          star.cutoffs = c(.1, .05, .01, .001), star.char = c("+", "*", "**", "***"),
          notes = c("+ p<0.1; * p<0.05; ** p<0.01; *** p<0.001"), notes.append = FALSE,
          type = "html", out = "Online Appendix Table 4")

stargazer(model2, 
          dep.var.labels=c("Decision Acceptance"),
          covariate.labels=c("Bill Failed", 
                             "Consultation: Polling", "Consultation: Interested", "Consultation: Affected",
                             "Bill Failed * Polling", "Bill Failed * Interested", "Bill Failed * Affected"),
          single.row = TRUE, no.space=TRUE,
          star.cutoffs = c(.1, .05, .01, .001), star.char = c("+", "*", "**", "***"),
          notes = c("+ p<0.1; * p<0.05; ** p<0.01; *** p<0.001"), notes.append = FALSE,
          type = "html", out = "Appendix Table 3")

stargazer(model2_own, 
          dep.var.labels=c("Decision Acceptance"),
          order = c(1, 2, 3, 4, 9, 10, 11),
          covariate.labels=c("Bill Failed", 
                             "Consultation: Polling", "Consultation: Interested", "Consultation: Affected",
                             "Bill Failed * Polling", "Bill Failed * Interested", "Bill Failed * Affected",
                             "Just above Bottom 25%", "Around the Middle", "Just below Top 25%", "Top 25%"), 
          single.row = TRUE, no.space=TRUE,
          star.cutoffs = c(.1, .05, .01, .001), star.char = c("+", "*", "**", "***"),
          notes = c("+ p<0.1; * p<0.05; ** p<0.01; *** p<0.001"), notes.append = FALSE,
          type = "html", out = "Online Appendix Table 5")

stargazer(model2_hh, 
          dep.var.labels=c("Decision Acceptance"),
          order = c(1, 2, 3, 4, 9, 10, 11),
          covariate.labels=c("Bill Failed", 
                             "Consultation: Polling", "Consultation: Interested", "Consultation: Affected",
                             "Bill Failed * Polling", "Bill Failed * Interested", "Bill Failed * Affected",
                             "Just above Bottom 25%", "Around the Middle", "Just below Top 25%", "Top 25%"), 
          single.row = TRUE, no.space=TRUE,
          star.cutoffs = c(.1, .05, .01, .001), star.char = c("+", "*", "**", "***"),
          notes = c("+ p<0.1; * p<0.05; ** p<0.01; *** p<0.001"), notes.append = FALSE,
          type = "html", out = "Online Appendix Table 6")

stargazer(model3, model4,
          dep.var.labels=c("Decision Acceptance"),
          covariate.labels=c("Bill Failed", "Internal Efficacy",
                             "Consultation: Polling", "Consultation: Interested", "Consultation: Affected",
                             "External Efficacy", "Bill Failed * Internal Efficacy",
                             "Bill Failed * Polling", "Bill Failed * Interested", "Bill Failed * Affected", 
                             "Bill Failed * External Efficacy",
                             "Polling * External Efficacy", 
                             "Interested * External Efficacy", 
                             "Affected * External Efficacy", 
                             "Bill Failed * Polling * External Efficacy", 
                             "Bill Failed * Interested * External Efficacy", 
                             "Bill Failed * Affected * External Efficacy", 
                             "Polling * Internal Efficacy", 
                             "Interested * Internal Efficacy", 
                             "Affected * Internal Efficacy", 
                             "Bill Failed * Polling * Internal Efficacy", 
                             "Bill Failed * Interested * Internal Efficacy", 
                             "Bill Failed * Affected * Internal Efficacy"),
          single.row = TRUE, no.space=TRUE,        
          star.cutoffs = c(.1, .05, .01, .001), star.char = c("+", "*", "**", "***"),
          notes = c("+ p<0.1; * p<0.05; ** p<0.01; *** p<0.001"), notes.append = FALSE,
          type = "html", out = "Appendix Table 4")

stargazer(model3_own, model4_own,
          dep.var.labels=c("Decision Acceptance"),
          order = c(1, 2, 3, 4, 5, 6, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27),
          covariate.labels=c("Bill Failed", "Internal Efficacy",
                             "Consultation: Polling", "Consultation: Interested", "Consultation: Affected",
                             "External Efficacy", "Bill Failed * Internal Efficacy",
                             "Bill Failed * Polling", "Bill Failed * Interested", "Bill Failed * Affected", 
                             "Bill Failed * External Efficacy",
                             "Polling * External Efficacy", 
                             "Interested * External Efficacy", 
                             "Affected * External Efficacy", 
                             "Bill Failed * Polling * External Efficacy", 
                             "Bill Failed * Interested * External Efficacy", 
                             "Bill Failed * Affected * External Efficacy", 
                             "Polling * Internal Efficacy", 
                             "Interested * Internal Efficacy", 
                             "Affected * Internal Efficacy", 
                             "Bill Failed * Polling * Internal Efficacy", 
                             "Bill Failed * Interested * Internal Efficacy", 
                             "Bill Failed * Affected * Internal Efficacy",
                             "Just above Bottom 25%", "Around the Middle", "Just below Top 25%", "Top 25%"),
          single.row = TRUE, no.space=TRUE,        
          star.cutoffs = c(.1, .05, .01, .001), star.char = c("+", "*", "**", "***"),
          notes = c("+ p<0.1; * p<0.05; ** p<0.01; *** p<0.001"), notes.append = FALSE,
          type = "html", out = "Online Appendix Table 7")

stargazer(model3_hh, model4_hh,
          dep.var.labels=c("Decision Acceptance"),
          order = c(1, 2, 3, 4, 5, 6, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27),
          covariate.labels=c("Bill Failed", "Internal Efficacy",
                             "Consultation: Polling", "Consultation: Interested", "Consultation: Affected",
                             "External Efficacy", "Bill Failed * Internal Efficacy",
                             "Bill Failed * Polling", "Bill Failed * Interested", "Bill Failed * Affected", 
                             "Bill Failed * External Efficacy",
                             "Polling * External Efficacy", 
                             "Interested * External Efficacy", 
                             "Affected * External Efficacy", 
                             "Bill Failed * Polling * External Efficacy", 
                             "Bill Failed * Interested * External Efficacy", 
                             "Bill Failed * Affected * External Efficacy", 
                             "Polling * Internal Efficacy", 
                             "Interested * Internal Efficacy", 
                             "Affected * Internal Efficacy", 
                             "Bill Failed * Polling * Internal Efficacy", 
                             "Bill Failed * Interested * Internal Efficacy", 
                             "Bill Failed * Affected * Internal Efficacy",
                             "Just above Bottom 25%", "Around the Middle", "Just below Top 25%", "Top 25%"),
          single.row = TRUE, no.space=TRUE,        
          star.cutoffs = c(.1, .05, .01, .001), star.char = c("+", "*", "**", "***"),
          notes = c("+ p<0.1; * p<0.05; ** p<0.01; *** p<0.001"), notes.append = FALSE,
          type = "html", out = "Online Appendix Table 8")

